Datasets — Django-Vitae 0.0.1 documentation

# Datasets

Django-Vitae includes a model to describe datasets produced by the author. The `Dataset` class stores instances of these datasets.

The `Dataset` model has three required fields:

- `title`
- `short_title`
- `slug`

The `Dataset` model also includes an `authorship` field that allows for authorships of the `Dataset`. The authorships are related to the `Dataset` through a foreign-key relationship to the `DatasetAuthorship` model. This model works the same way that the authorship sets on publications.

A full description of fields can be found in the `Dataset` field reference.